@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright 2020 Google LLC
+# Copyright 2022 Google LLC
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -227,6 +227,33 @@ class IndexEndpointServiceAsyncClient:
     ) -> operation_async.AsyncOperation:
         r"""Creates an IndexEndpoint.
 
+        .. code-block:: python
+
+            from google.cloud import aiplatform_v1
+
+            def sample_create_index_endpoint():
+                # Create a client
+                client = aiplatform_v1.IndexEndpointServiceClient()
+
+                # Initialize request argument(s)
+                index_endpoint = aiplatform_v1.IndexEndpoint()
+                index_endpoint.display_name = "display_name_value"
+
+                request = aiplatform_v1.CreateIndexEndpointRequest(
+                    parent="parent_value",
+                    index_endpoint=index_endpoint,
+                )
+
+                # Make the request
+                operation = client.create_index_endpoint(request=request)
+
+                print("Waiting for operation to complete...")
+
+                response = operation.result()
+
+                # Handle the response
+                print(response)
+
         Args:
             request (Union[google.cloud.aiplatform_v1.types.CreateIndexEndpointRequest, dict]):
                 The request object. Request message for
@@ -294,7 +321,12 @@ class IndexEndpointServiceAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Wrap the response in an operation future.
         response = operation_async.from_gapic(
@@ -318,6 +350,25 @@ class IndexEndpointServiceAsyncClient:
     ) -> index_endpoint.IndexEndpoint:
         r"""Gets an IndexEndpoint.
 
+        .. code-block:: python
+
+            from google.cloud import aiplatform_v1
+
+            def sample_get_index_endpoint():
+                # Create a client
+                client = aiplatform_v1.IndexEndpointServiceClient()
+
+                # Initialize request argument(s)
+                request = aiplatform_v1.GetIndexEndpointRequest(
+                    name="name_value",
+                )
+
+                # Make the request
+                response = client.get_index_endpoint(request=request)
+
+                # Handle the response
+                print(response)
+
         Args:
             request (Union[google.cloud.aiplatform_v1.types.GetIndexEndpointRequest, dict]):
                 The request object. Request message for
@@ -375,7 +426,12 @@ class IndexEndpointServiceAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Done; return the response.
         return response
@@ -391,6 +447,26 @@ class IndexEndpointServiceAsyncClient:
     ) -> pagers.ListIndexEndpointsAsyncPager:
         r"""Lists IndexEndpoints in a Location.
 
+        .. code-block:: python
+
+            from google.cloud import aiplatform_v1
+
+            def sample_list_index_endpoints():
+                # Create a client
+                client = aiplatform_v1.IndexEndpointServiceClient()
+
+                # Initialize request argument(s)
+                request = aiplatform_v1.ListIndexEndpointsRequest(
+                    parent="parent_value",
+                )
+
+                # Make the request
+                page_result = client.list_index_endpoints(request=request)
+
+                # Handle the response
+                for response in page_result:
+                    print(response)
+
         Args:
             request (Union[google.cloud.aiplatform_v1.types.ListIndexEndpointsRequest, dict]):
                 The request object. Request message for
@@ -450,12 +526,20 @@ class IndexEndpointServiceAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # This method is paged; wrap the response in a pager, which provides
         # an `__aiter__` convenience method.
         response = pagers.ListIndexEndpointsAsyncPager(
-            method=rpc, request=request, response=response, metadata=metadata,
+            method=rpc,
+            request=request,
+            response=response,
+            metadata=metadata,
         )
 
         # Done; return the response.
@@ -473,6 +557,28 @@ class IndexEndpointServiceAsyncClient:
     ) -> gca_index_endpoint.IndexEndpoint:
         r"""Updates an IndexEndpoint.
 
+        .. code-block:: python
+
+            from google.cloud import aiplatform_v1
+
+            def sample_update_index_endpoint():
+                # Create a client
+                client = aiplatform_v1.IndexEndpointServiceClient()
+
+                # Initialize request argument(s)
+                index_endpoint = aiplatform_v1.IndexEndpoint()
+                index_endpoint.display_name = "display_name_value"
+
+                request = aiplatform_v1.UpdateIndexEndpointRequest(
+                    index_endpoint=index_endpoint,
+                )
+
+                # Make the request
+                response = client.update_index_endpoint(request=request)
+
+                # Handle the response
+                print(response)
+
         Args:
             request (Union[google.cloud.aiplatform_v1.types.UpdateIndexEndpointRequest, dict]):
                 The request object. Request message for
@@ -540,7 +646,12 @@ class IndexEndpointServiceAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Done; return the response.
         return response
@@ -556,6 +667,29 @@ class IndexEndpointServiceAsyncClient:
     ) -> operation_async.AsyncOperation:
         r"""Deletes an IndexEndpoint.
 
+        .. code-block:: python
+
+            from google.cloud import aiplatform_v1
+
+            def sample_delete_index_endpoint():
+                # Create a client
+                client = aiplatform_v1.IndexEndpointServiceClient()
+
+                # Initialize request argument(s)
+                request = aiplatform_v1.DeleteIndexEndpointRequest(
+                    name="name_value",
+                )
+
+                # Make the request
+                operation = client.delete_index_endpoint(request=request)
+
+                print("Waiting for operation to complete...")
+
+                response = operation.result()
+
+                # Handle the response
+                print(response)
+
         Args:
             request (Union[google.cloud.aiplatform_v1.types.DeleteIndexEndpointRequest, dict]):
                 The request object. Request message for
@@ -625,7 +759,12 @@ class IndexEndpointServiceAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Wrap the response in an operation future.
         response = operation_async.from_gapic(
@@ -652,6 +791,35 @@ class IndexEndpointServiceAsyncClient:
         DeployedIndex within it.
         Only non-empty Indexes can be deployed.
 
+
+        .. code-block:: python
+
+            from google.cloud import aiplatform_v1
+
+            def sample_deploy_index():
+                # Create a client
+                client = aiplatform_v1.IndexEndpointServiceClient()
+
+                # Initialize request argument(s)
+                deployed_index = aiplatform_v1.DeployedIndex()
+                deployed_index.id = "id_value"
+                deployed_index.index = "index_value"
+
+                request = aiplatform_v1.DeployIndexRequest(
+                    index_endpoint="index_endpoint_value",
+                    deployed_index=deployed_index,
+                )
+
+                # Make the request
+                operation = client.deploy_index(request=request)
+
+                print("Waiting for operation to complete...")
+
+                response = operation.result()
+
+                # Handle the response
+                print(response)
+
         Args:
             request (Union[google.cloud.aiplatform_v1.types.DeployIndexRequest, dict]):
                 The request object. Request message for
@@ -723,7 +891,12 @@ class IndexEndpointServiceAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Wrap the response in an operation future.
         response = operation_async.from_gapic(
@@ -750,6 +923,31 @@ class IndexEndpointServiceAsyncClient:
         DeployedIndex from it, and freeing all resources it's
         using.
 
+
+        .. code-block:: python
+
+            from google.cloud import aiplatform_v1
+
+            def sample_undeploy_index():
+                # Create a client
+                client = aiplatform_v1.IndexEndpointServiceClient()
+
+                # Initialize request argument(s)
+                request = aiplatform_v1.UndeployIndexRequest(
+                    index_endpoint="index_endpoint_value",
+                    deployed_index_id="deployed_index_id_value",
+                )
+
+                # Make the request
+                operation = client.undeploy_index(request=request)
+
+                print("Waiting for operation to complete...")
+
+                response = operation.result()
+
+                # Handle the response
+                print(response)
+
         Args:
             request (Union[google.cloud.aiplatform_v1.types.UndeployIndexRequest, dict]):
                 The request object. Request message for
@@ -821,7 +1019,12 @@ class IndexEndpointServiceAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Wrap the response in an operation future.
         response = operation_async.from_gapic(
@@ -847,6 +1050,35 @@ class IndexEndpointServiceAsyncClient:
         r"""Update an existing DeployedIndex under an
         IndexEndpoint.
 
+
+        .. code-block:: python
+
+            from google.cloud import aiplatform_v1
+
+            def sample_mutate_deployed_index():
+                # Create a client
+                client = aiplatform_v1.IndexEndpointServiceClient()
+
+                # Initialize request argument(s)
+                deployed_index = aiplatform_v1.DeployedIndex()
+                deployed_index.id = "id_value"
+                deployed_index.index = "index_value"
+
+                request = aiplatform_v1.MutateDeployedIndexRequest(
+                    index_endpoint="index_endpoint_value",
+                    deployed_index=deployed_index,
+                )
+
+                # Make the request
+                operation = client.mutate_deployed_index(request=request)
+
+                print("Waiting for operation to complete...")
+
+                response = operation.result()
+
+                # Handle the response
+                print(response)
+
         Args:
             request (Union[google.cloud.aiplatform_v1.types.MutateDeployedIndexRequest, dict]):
                 The request object. Request message for
@@ -920,7 +1152,12 @@ class IndexEndpointServiceAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Wrap the response in an operation future.
         response = operation_async.from_gapic(
