@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright 2020 Google LLC
+# Copyright 2022 Google LLC
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -64,7 +64,10 @@ class EndpointServiceClientMeta(type):
     _transport_registry["grpc"] = EndpointServiceGrpcTransport
     _transport_registry["grpc_asyncio"] = EndpointServiceGrpcAsyncIOTransport
 
-    def get_transport_class(cls, label: str = None,) -> Type[EndpointServiceTransport]:
+    def get_transport_class(
+        cls,
+        label: str = None,
+    ) -> Type[EndpointServiceTransport]:
         """Returns an appropriate transport class.
 
         Args:
@@ -169,10 +172,16 @@ class EndpointServiceClient(metaclass=EndpointServiceClientMeta):
         return self._transport
 
     @staticmethod
-    def endpoint_path(project: str, location: str, endpoint: str,) -> str:
+    def endpoint_path(
+        project: str,
+        location: str,
+        endpoint: str,
+    ) -> str:
         """Returns a fully-qualified endpoint string."""
         return "projects/{project}/locations/{location}/endpoints/{endpoint}".format(
-            project=project, location=location, endpoint=endpoint,
+            project=project,
+            location=location,
+            endpoint=endpoint,
         )
 
     @staticmethod
@@ -185,10 +194,16 @@ class EndpointServiceClient(metaclass=EndpointServiceClientMeta):
         return m.groupdict() if m else {}
 
     @staticmethod
-    def model_path(project: str, location: str, model: str,) -> str:
+    def model_path(
+        project: str,
+        location: str,
+        model: str,
+    ) -> str:
         """Returns a fully-qualified model string."""
         return "projects/{project}/locations/{location}/models/{model}".format(
-            project=project, location=location, model=model,
+            project=project,
+            location=location,
+            model=model,
         )
 
     @staticmethod
@@ -202,7 +217,9 @@ class EndpointServiceClient(metaclass=EndpointServiceClientMeta):
 
     @staticmethod
     def model_deployment_monitoring_job_path(
-        project: str, location: str, model_deployment_monitoring_job: str,
+        project: str,
+        location: str,
+        model_deployment_monitoring_job: str,
     ) -> str:
         """Returns a fully-qualified model_deployment_monitoring_job string."""
         return "projects/{project}/locations/{location}/modelDeploymentMonitoringJobs/{model_deployment_monitoring_job}".format(
@@ -221,10 +238,14 @@ class EndpointServiceClient(metaclass=EndpointServiceClientMeta):
         return m.groupdict() if m else {}
 
     @staticmethod
-    def network_path(project: str, network: str,) -> str:
+    def network_path(
+        project: str,
+        network: str,
+    ) -> str:
         """Returns a fully-qualified network string."""
         return "projects/{project}/global/networks/{network}".format(
-            project=project, network=network,
+            project=project,
+            network=network,
         )
 
     @staticmethod
@@ -236,7 +257,9 @@ class EndpointServiceClient(metaclass=EndpointServiceClientMeta):
         return m.groupdict() if m else {}
 
     @staticmethod
-    def common_billing_account_path(billing_account: str,) -> str:
+    def common_billing_account_path(
+        billing_account: str,
+    ) -> str:
         """Returns a fully-qualified billing_account string."""
         return "billingAccounts/{billing_account}".format(
             billing_account=billing_account,
@@ -249,9 +272,13 @@ class EndpointServiceClient(metaclass=EndpointServiceClientMeta):
         return m.groupdict() if m else {}
 
     @staticmethod
-    def common_folder_path(folder: str,) -> str:
+    def common_folder_path(
+        folder: str,
+    ) -> str:
         """Returns a fully-qualified folder string."""
-        return "folders/{folder}".format(folder=folder,)
+        return "folders/{folder}".format(
+            folder=folder,
+        )
 
     @staticmethod
     def parse_common_folder_path(path: str) -> Dict[str, str]:
@@ -260,9 +287,13 @@ class EndpointServiceClient(metaclass=EndpointServiceClientMeta):
         return m.groupdict() if m else {}
 
     @staticmethod
-    def common_organization_path(organization: str,) -> str:
+    def common_organization_path(
+        organization: str,
+    ) -> str:
         """Returns a fully-qualified organization string."""
-        return "organizations/{organization}".format(organization=organization,)
+        return "organizations/{organization}".format(
+            organization=organization,
+        )
 
     @staticmethod
     def parse_common_organization_path(path: str) -> Dict[str, str]:
@@ -271,9 +302,13 @@ class EndpointServiceClient(metaclass=EndpointServiceClientMeta):
         return m.groupdict() if m else {}
 
     @staticmethod
-    def common_project_path(project: str,) -> str:
+    def common_project_path(
+        project: str,
+    ) -> str:
         """Returns a fully-qualified project string."""
-        return "projects/{project}".format(project=project,)
+        return "projects/{project}".format(
+            project=project,
+        )
 
     @staticmethod
     def parse_common_project_path(path: str) -> Dict[str, str]:
@@ -282,10 +317,14 @@ class EndpointServiceClient(metaclass=EndpointServiceClientMeta):
         return m.groupdict() if m else {}
 
     @staticmethod
-    def common_location_path(project: str, location: str,) -> str:
+    def common_location_path(
+        project: str,
+        location: str,
+    ) -> str:
         """Returns a fully-qualified location string."""
         return "projects/{project}/locations/{location}".format(
-            project=project, location=location,
+            project=project,
+            location=location,
         )
 
     @staticmethod
@@ -472,6 +511,33 @@ class EndpointServiceClient(metaclass=EndpointServiceClientMeta):
     ) -> gac_operation.Operation:
         r"""Creates an Endpoint.
 
+        .. code-block:: python
+
+            from google.cloud import aiplatform_v1beta1
+
+            def sample_create_endpoint():
+                # Create a client
+                client = aiplatform_v1beta1.EndpointServiceClient()
+
+                # Initialize request argument(s)
+                endpoint = aiplatform_v1beta1.Endpoint()
+                endpoint.display_name = "display_name_value"
+
+                request = aiplatform_v1beta1.CreateEndpointRequest(
+                    parent="parent_value",
+                    endpoint=endpoint,
+                )
+
+                # Make the request
+                operation = client.create_endpoint(request=request)
+
+                print("Waiting for operation to complete...")
+
+                response = operation.result()
+
+                # Handle the response
+                print(response)
+
         Args:
             request (Union[google.cloud.aiplatform_v1beta1.types.CreateEndpointRequest, dict]):
                 The request object. Request message for
@@ -554,7 +620,12 @@ class EndpointServiceClient(metaclass=EndpointServiceClientMeta):
         )
 
         # Send the request.
-        response = rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Wrap the response in an operation future.
         response = gac_operation.from_gapic(
@@ -578,6 +649,25 @@ class EndpointServiceClient(metaclass=EndpointServiceClientMeta):
     ) -> endpoint.Endpoint:
         r"""Gets an Endpoint.
 
+        .. code-block:: python
+
+            from google.cloud import aiplatform_v1beta1
+
+            def sample_get_endpoint():
+                # Create a client
+                client = aiplatform_v1beta1.EndpointServiceClient()
+
+                # Initialize request argument(s)
+                request = aiplatform_v1beta1.GetEndpointRequest(
+                    name="name_value",
+                )
+
+                # Make the request
+                response = client.get_endpoint(request=request)
+
+                # Handle the response
+                print(response)
+
         Args:
             request (Union[google.cloud.aiplatform_v1beta1.types.GetEndpointRequest, dict]):
                 The request object. Request message for
@@ -634,7 +724,12 @@ class EndpointServiceClient(metaclass=EndpointServiceClientMeta):
         )
 
         # Send the request.
-        response = rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Done; return the response.
         return response
@@ -650,6 +745,26 @@ class EndpointServiceClient(metaclass=EndpointServiceClientMeta):
     ) -> pagers.ListEndpointsPager:
         r"""Lists Endpoints in a Location.
 
+        .. code-block:: python
+
+            from google.cloud import aiplatform_v1beta1
+
+            def sample_list_endpoints():
+                # Create a client
+                client = aiplatform_v1beta1.EndpointServiceClient()
+
+                # Initialize request argument(s)
+                request = aiplatform_v1beta1.ListEndpointsRequest(
+                    parent="parent_value",
+                )
+
+                # Make the request
+                page_result = client.list_endpoints(request=request)
+
+                # Handle the response
+                for response in page_result:
+                    print(response)
+
         Args:
             request (Union[google.cloud.aiplatform_v1beta1.types.ListEndpointsRequest, dict]):
                 The request object. Request message for
@@ -709,12 +824,20 @@ class EndpointServiceClient(metaclass=EndpointServiceClientMeta):
         )
 
         # Send the request.
-        response = rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # This method is paged; wrap the response in a pager, which provides
         # an `__iter__` convenience method.
         response = pagers.ListEndpointsPager(
-            method=rpc, request=request, response=response, metadata=metadata,
+            method=rpc,
+            request=request,
+            response=response,
+            metadata=metadata,
         )
 
         # Done; return the response.
@@ -732,6 +855,28 @@ class EndpointServiceClient(metaclass=EndpointServiceClientMeta):
     ) -> gca_endpoint.Endpoint:
         r"""Updates an Endpoint.
 
+        .. code-block:: python
+
+            from google.cloud import aiplatform_v1beta1
+
+            def sample_update_endpoint():
+                # Create a client
+                client = aiplatform_v1beta1.EndpointServiceClient()
+
+                # Initialize request argument(s)
+                endpoint = aiplatform_v1beta1.Endpoint()
+                endpoint.display_name = "display_name_value"
+
+                request = aiplatform_v1beta1.UpdateEndpointRequest(
+                    endpoint=endpoint,
+                )
+
+                # Make the request
+                response = client.update_endpoint(request=request)
+
+                # Handle the response
+                print(response)
+
         Args:
             request (Union[google.cloud.aiplatform_v1beta1.types.UpdateEndpointRequest, dict]):
                 The request object. Request message for
@@ -799,7 +944,12 @@ class EndpointServiceClient(metaclass=EndpointServiceClientMeta):
         )
 
         # Send the request.
-        response = rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Done; return the response.
         return response
@@ -815,6 +965,29 @@ class EndpointServiceClient(metaclass=EndpointServiceClientMeta):
     ) -> gac_operation.Operation:
         r"""Deletes an Endpoint.
 
+        .. code-block:: python
+
+            from google.cloud import aiplatform_v1beta1
+
+            def sample_delete_endpoint():
+                # Create a client
+                client = aiplatform_v1beta1.EndpointServiceClient()
+
+                # Initialize request argument(s)
+                request = aiplatform_v1beta1.DeleteEndpointRequest(
+                    name="name_value",
+                )
+
+                # Make the request
+                operation = client.delete_endpoint(request=request)
+
+                print("Waiting for operation to complete...")
+
+                response = operation.result()
+
+                # Handle the response
+                print(response)
+
         Args:
             request (Union[google.cloud.aiplatform_v1beta1.types.DeleteEndpointRequest, dict]):
                 The request object. Request message for
@@ -884,7 +1057,12 @@ class EndpointServiceClient(metaclass=EndpointServiceClientMeta):
         )
 
         # Send the request.
-        response = rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Wrap the response in an operation future.
         response = gac_operation.from_gapic(
@@ -913,6 +1091,35 @@ class EndpointServiceClient(metaclass=EndpointServiceClientMeta):
         r"""Deploys a Model into this Endpoint, creating a
         DeployedModel within it.
 
+
+        .. code-block:: python
+
+            from google.cloud import aiplatform_v1beta1
+
+            def sample_deploy_model():
+                # Create a client
+                client = aiplatform_v1beta1.EndpointServiceClient()
+
+                # Initialize request argument(s)
+                deployed_model = aiplatform_v1beta1.DeployedModel()
+                deployed_model.dedicated_resources.min_replica_count = 1803
+                deployed_model.model = "model_value"
+
+                request = aiplatform_v1beta1.DeployModelRequest(
+                    endpoint="endpoint_value",
+                    deployed_model=deployed_model,
+                )
+
+                # Make the request
+                operation = client.deploy_model(request=request)
+
+                print("Waiting for operation to complete...")
+
+                response = operation.result()
+
+                # Handle the response
+                print(response)
+
         Args:
             request (Union[google.cloud.aiplatform_v1beta1.types.DeployModelRequest, dict]):
                 The request object. Request message for
@@ -1008,7 +1215,12 @@ class EndpointServiceClient(metaclass=EndpointServiceClientMeta):
         )
 
         # Send the request.
-        response = rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Wrap the response in an operation future.
         response = gac_operation.from_gapic(
@@ -1038,6 +1250,31 @@ class EndpointServiceClient(metaclass=EndpointServiceClientMeta):
         DeployedModel from it, and freeing all resources it's
         using.
 
+
+        .. code-block:: python
+
+            from google.cloud import aiplatform_v1beta1
+
+            def sample_undeploy_model():
+                # Create a client
+                client = aiplatform_v1beta1.EndpointServiceClient()
+
+                # Initialize request argument(s)
+                request = aiplatform_v1beta1.UndeployModelRequest(
+                    endpoint="endpoint_value",
+                    deployed_model_id="deployed_model_id_value",
+                )
+
+                # Make the request
+                operation = client.undeploy_model(request=request)
+
+                print("Waiting for operation to complete...")
+
+                response = operation.result()
+
+                # Handle the response
+                print(response)
+
         Args:
             request (Union[google.cloud.aiplatform_v1beta1.types.UndeployModelRequest, dict]):
                 The request object. Request message for
@@ -1123,7 +1360,12 @@ class EndpointServiceClient(metaclass=EndpointServiceClientMeta):
         )
 
         # Send the request.
-        response = rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Wrap the response in an operation future.
         response = gac_operation.from_gapic(
